@@ -7,14 +7,22 @@ def showUrl(url, logger=None):
 
     Currently just shells out to gnome-open, which uses the browser
     picked in the Gnome "preferred applications" control panel.
+    If firefox is used open a new window.
     If Gnome is not available it uses the x-www-browser setting
     """
     if logger:
         logger.info('opening URL %s', url)
     
-    if os.path.exists('/usr/bin/gnome-open'):
-        command = ['gnome-open', url]
-    elif os.path.exists('/usr/bin/kfmclient'):
+    if os.environ.get('GNOME_DESKTOP_SESSION_ID') and os.path.exists('/usr/bin/gnome-open'):
+	command = ['gnome-open', url]
+	if os.path.exists('/usr/bin/gconftool-2'):
+		gconf_key = os.popen('gconftool-2 --get /desktop/gnome/url-handlers/http/command')
+		if gconf_key.read().strip() == 'firefox %s':
+			if (subprocess.call(['firefox', '-remote', 'ping()'], stderr=open('/dev/null', 'w')) == 0):
+				command = ['firefox', '-remote', 'openURL(%s, new-window)'%url]
+			else:
+				command = ['firefox', url]
+    elif os.environ.get('KDE_FULL_SESSION') and os.path.exists('/usr/bin/kfmclient'):
         command = ['kfmclient', 'openURL', url]
     else:
         command = ['x-www-browser', url]
